@@ -177,6 +177,7 @@ FCKConfig.FlashDlgHideAdvanced	= false ;
 // Tags for FCKW
 FCKConfig.ProtectedTags = 'indent' ;
 FCKConfig.ProtectedTags = 'header' ;
+FCKConfig.ProtectedTags = 'plugin' ;
 
 // This will be applied to the body element of the editor
 FCKConfig.BodyId = '' ;
@@ -311,7 +312,7 @@ FCKConfig.SmileyWindowWidth		= 320 ;
 FCKConfig.SmileyWindowHeight	= 240 ;
 
 // FCKConfig.Plugins.Add( 'placeholder', 'en,it' ) ;
-// FCKConfig.Plugins.Add( 'Abbr','en') ; 
+FCKConfig.Plugins.Add( 'Abbr','en') ; 
 // FCKConfig.Plugins.Add( 'dwikimedia' ) ;
 
 FCKConfig.ToolbarSets["Dokuwiki"] = [   
@@ -319,13 +320,14 @@ FCKConfig.ToolbarSets["Dokuwiki"] = [
   ['OrderedList','UnorderedList'],['Outdent','Indent'],   
   ['JustifyCenter','JustifyLeft','JustifyRight'],
   ['Table','Rule', 'Blockquote'], ['Smiley', 'SpecialChar'], [],  
-  ['Cut','Copy','Paste','PasteText' ],   
+  ['Cut','Copy','Paste','PasteText', 'PasteWord' ],   
   ['Undo','Redo','RemoveFormat', '-','Find'],   
   '/',   
   ['Style'],
   ['TextColor','BGColor'],['FontFormat','FontName','FontSize'], 
   
-   ['Link','Unlink'], ['Image'],  
+   ['Link','Unlink'], ['Image', 'Abbr'],  
+ //  ['Link','Unlink'], ['Image'],  
   '/',
 
   ['Source','-','About']   
